@@ -4,6 +4,7 @@ push(@::bean_desc, {
     bean_opt => {
         abstract => 'Unique, associative MULTI bean attribute information',
         package => 'PerlBean::Attribute::Multi::Unique::Associative',
+        use_perl_version => 5.005,
         base => [ qw(PerlBean::Attribute::Multi)],
         description => <<EOF,
 C<PerlBean::Attribute::Multi::Unique::Associative> contains unique associative MULTI bean attribute information. It is a subclass of C<PerlBean::Attribute::Multi>. The code generation and documentation methods from C<PerlBean::Attribute> are implemented.
@@ -33,6 +34,21 @@ __SUPER_POD__ Access methods are B<set...>, B<add...>, B<delete...>, B<exists...
 EOF
         },
     ],
+    sym_opt => [
+        {
+            symbol_name => '$SUB',
+            comment => <<EOF,
+# Variable to not confuse AutoLoader
+EOF
+            assignment => "'sub';\n",
+        },
+    ],
+    use_opt => [
+        {
+            dependency_name => 'PerlBean::Style',
+            import_list => [ 'qw(:codegen)' ],
+        },
+    ],
 } );
 
 sub get_syn {
